#
# spec file for package NetworkManager-iodine
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           NetworkManager-iodine
Version:        1.2.0
Release:        bp160.1.8
Summary:        NetworkManager VPN support for iodine
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://honk.sigxcpu.org/piki/projects/network-manager-iodine/
Source0:        http://download.gnome.org/sources/NetworkManager-iodine/1.2/%{name}-%{version}.tar.xz
Source1:        system-user-nm-iodine.conf
# PATCH-FIX-UPSTREAM NetworkManager-iodine-pkgconf-2.1.0.patch glgo#GNOME/network-manager-iodine!5
Patch0:         NetworkManager-iodine-pkgconf-2.1.0.patch
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(gtk+-3.0) >= 2.91.4
BuildRequires:  pkgconfig(libnm) >= 1.1.0
BuildRequires:  pkgconfig(libnma) >= 1.1.0
BuildRequires:  pkgconfig(libsecret-1)
Requires:       NetworkManager >= 1.1.0
Requires:       iodine >= 0.6.0rc1
Supplements:    (NetworkManager and iodine)

%description
A network manager VPN plugin that allows you to tunnel your connection
through a DNS tunnel. This can be useful if internet access is
firewalled but DNS traffic is still allowed.

%package -n NetworkManager-applet-iodine
Summary:        NetworkManager VPN support for iodine
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-gnome = %{version}
Obsoletes:      %{name}-gnome
Supplements:    (%{name} and NetworkManager-applet)
Supplements:    (%{name} and gnome-control-center)

%description -n NetworkManager-applet-iodine
A network manager VPN plugin that allows you to tunnel your connection
through a DNS tunnel. This can be useful if internet access is
firewalled but DNS traffic is still allowed.

%lang_package

%prep
%autosetup -p1

%build
autoreconf -fiv
%sysusers_generate_pre %{SOURCE1} %{name} %{name}.conf
%configure \
           --disable-static \
           --disable-more-warnings \
           --without-libnm-glib \
           %{nil}
make %{?_smp_mflags}

%install
%make_install dbusservicedir=%{_datadir}/dbus-1/system.d
install -Dm0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/%{name}.conf
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%pre -f %{name}.pre

%files
%license COPYING
%doc AUTHORS NEWS
%{_sysusersdir}/%{name}.conf
%{_libdir}/NetworkManager/libnm-vpn-plugin-iodine.so
%{_vpnservicedir}/nm-iodine-service.name
%{_libexecdir}/nm-iodine-service
%{_datadir}/dbus-1/system.d/nm-iodine-service.conf

%files -n NetworkManager-applet-iodine
%{_datadir}/appdata/network-manager-iodine.appdata.xml
%{_datadir}/gnome-vpn-properties/
%{_libexecdir}/nm-iodine-auth-dialog

%files lang -f %{name}.lang

%changelog
* Thu Mar 28 2024 Jonathan Kang <songchuan.kang@suse.com>
- Add missing supplements(bsc#1220391):
  + NMA subpackage: Main package and gnome-control-center
* Thu Feb 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add NetworkManager-iodine-pkgconf-2.1.0.patch: Fix
  build/installation when using pkgconf 2.1 as pkg-config
  implementation: configure wrongly called
  "pkg-config pkg-config --parameters", which now leads nowhere.
- Add libtool BuildRequires and call autoreconf, as above patch
  touches the build system.
* Fri Dec  1 2023 Callum Farmer <gmbr3@opensuse.org>
- Rename gnome subpackage to NetworkManager-applet-iodine
  to more accurately reflect its usage
- Change supplements:
  - NMA subpackage: only supplement if main package is installed
* Wed Dec 28 2022 Callum Farmer <gmbr3@opensuse.org>
- Move dbus-1 system.d conf file to /usr (bsc#1206756)
* Sat Feb 19 2022 Callum Farmer <gmbr3@opensuse.org>
- Create nm-iodine user (by systemd-sysusers)
- Update Supplements to new format
* Fri May  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Apr 14 2018 bjorn.lie@gmail.com
- Following changes in NetworkManager: pass without-libnm-glib to
  configure, no longer build deprecated libnm-glib support.
- Following the above changes: Drop no longer needed
  pkgconfig(NetworkManager), pkgconfig(libnm-glib),
  pkgconfig(libnm-glib-vpn), pkgconfig(libnm-gtk) and
  pkgconfig(libnm-util) BuildRequires.
- Drop unnneeded NetworkManager-gnome Requires from gnome
  sub-package, it is not longer of use for us.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Aug 29 2016 dimstar@opensuse.org
- Update to version 1.2.0:
  + Add appdata file.
  + build: don't include the full path to a plugin by default.
- Changes from version 1.1.0:
  + Port to libnm.
  + Updated translations.
- Add pkgconfig(libnm), pkgconfig(libnma), pkgconfig(libnm-util),
  pkgconfig(libnm-glib) and pkgconfig(libnm-glib-vpn)
  BuildRequires: new dependencies.
* Sun Oct 12 2014 dimstar@opensuse.org
- Update to version 0.0.5:
  + Use libsecret.
  + Use libnm-gtk.
  + Updated translations.
- Add pkgconfig(libnm-gtk) BuildRequires: new dependency.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-1), following upstream.
* Tue Feb 19 2013 zaitor@opensuse.org
- Update to version 0.0.4:
  + Check password write result to avoid warning.
  + Remove unused define.
  + Log connection information at message level.
  + Removed markup from UI file.
  + Add external ui support.
  + Updated translations.
* Thu Sep  6 2012 malcolmlewis@opensuse.org
- Initial build.
